@@ -3,11 +3,11 @@
 
 from __future__ import print_function
 
-import errno
 from io import BytesIO
 import logging
 import hashlib
 import os
+import questionary
 import re
 import requests
 import requests_cache
@@ -16,7 +16,8 @@ import subprocess
 import sys
 import tarfile
 import concurrent.futures
-from rich.progress import BarColumn, DownloadColumn, TransferSpeedColumn, Progress
+import rich
+import rich.progress
 from zipfile import ZipFile
 
 import nf_core
@@ -24,9 +25,12 @@ import nf_core.list
 import nf_core.utils
 
 log = logging.getLogger(__name__)
+stderr = rich.console.Console(
+    stderr=True, style="dim", highlight=False, force_terminal=nf_core.utils.rich_force_colors()
+)
 
 
-class DownloadProgress(Progress):
+class DownloadProgress(rich.progress.Progress):
     """Custom Progress bar class, allowing us to have two progress
     bars with different columns / layouts.
     """
@@ -36,7 +40,7 @@ class DownloadProgress(Progress):
             if task.fields.get("progress_type") == "summary":
                 self.columns = (
                     "[magenta]{task.description}",
-                    BarColumn(bar_width=None),
+                    rich.progress.BarColumn(bar_width=None),
                     "[progress.percentage]{task.percentage:>3.0f}%",
                     "•",
                     "[green]{task.completed}/{task.total} completed",
@@ -44,18 +48,18 @@ class DownloadProgress(Progress):
             if task.fields.get("progress_type") == "download":
                 self.columns = (
                     "[blue]{task.description}",
-                    BarColumn(bar_width=None),
+                    rich.progress.BarColumn(bar_width=None),
                     "[progress.percentage]{task.percentage:>3.1f}%",
                     "•",
-                    DownloadColumn(),
+                    rich.progress.DownloadColumn(),
                     "•",
-                    TransferSpeedColumn(),
+                    rich.progress.TransferSpeedColumn(),
                 )
             if task.fields.get("progress_type") == "singularity_pull":
                 self.columns = (
                     "[magenta]{task.description}",
                     "[blue]{task.fields[current_log]}",
-                    BarColumn(bar_width=None),
+                    rich.progress.BarColumn(bar_width=None),
                 )
             yield self.make_tasks_table([task])
 
@@ -74,12 +78,12 @@ class DownloadWorkflow(object):
 
     def __init__(
         self,
-        pipeline,
+        pipeline=None,
         release=None,
         outdir=None,
-        compress_type="tar.gz",
+        compress_type=None,
         force=False,
-        singularity=False,
+        container=None,
         singularity_cache_only=False,
         parallel_downloads=4,
     ):
@@ -88,38 +92,46 @@ class DownloadWorkflow(object):
         self.outdir = outdir
         self.output_filename = None
         self.compress_type = compress_type
-        if self.compress_type == "none":
-            self.compress_type = None
         self.force = force
-        self.singularity = singularity
+        self.container = container
         self.singularity_cache_only = singularity_cache_only
         self.parallel_downloads = parallel_downloads
 
-        # Sanity checks
-        if self.singularity_cache_only and not self.singularity:
-            log.error("Command has '--singularity-cache' set, but not '--singularity'")
-            sys.exit(1)
-
-        self.wf_name = None
+        self.wf_releases = {}
+        self.wf_branches = {}
         self.wf_sha = None
         self.wf_download_url = None
         self.nf_config = dict()
         self.containers = list()
 
+        # Fetch remote workflows
+        self.wfs = nf_core.list.Workflows()
+        self.wfs.get_remote_workflows()
+
     def download_workflow(self):
         """Starts a nf-core workflow download."""
+
         # Get workflow details
         try:
-            self.fetch_workflow_details(nf_core.list.Workflows())
-        except LookupError:
+            self.prompt_pipeline_name()
+            self.pipeline, self.wf_releases, self.wf_branches = nf_core.utils.get_repo_releases_branches(
+                self.pipeline, self.wfs
+            )
+            self.prompt_release()
+            self.get_release_hash()
+            self.prompt_container_download()
+            self.prompt_use_singularity_cachedir()
+            self.prompt_singularity_cachedir_only()
+            self.prompt_compression_type()
+        except AssertionError as e:
+            log.critical(e)
             sys.exit(1)
 
-        summary_log = [
-            "Pipeline release: '{}'".format(self.release),
-            "Pull singularity containers: '{}'".format("Yes" if self.singularity else "No"),
-        ]
-        if self.singularity and os.environ.get("NXF_SINGULARITY_CACHEDIR"):
-            summary_log.append("Using '$NXF_SINGULARITY_CACHEDIR': {}".format(os.environ["NXF_SINGULARITY_CACHEDIR"]))
+        summary_log = [f"Pipeline release: '{self.release}'", f"Pull containers: '{self.container}'"]
+        if self.container == "singularity" and os.environ.get("NXF_SINGULARITY_CACHEDIR") is not None:
+            summary_log.append(
+                "Using [blue]$NXF_SINGULARITY_CACHEDIR[/]': {}".format(os.environ["NXF_SINGULARITY_CACHEDIR"])
+            )
 
         # Set an output filename now that we have the outdir
         if self.compress_type is not None:
@@ -145,7 +157,7 @@ class DownloadWorkflow(object):
             os.remove(self.output_filename)
 
         # Summary log
-        log.info("Saving {}\n {}".format(self.pipeline, "\n ".join(summary_log)))
+        log.info("Saving '{}'\n {}".format(self.pipeline, "\n ".join(summary_log)))
 
         # Download the pipeline files
         log.info("Downloading workflow files from GitHub")
@@ -154,96 +166,186 @@ class DownloadWorkflow(object):
         # Download the centralised configs
         log.info("Downloading centralised configs from GitHub")
         self.download_configs()
-        self.wf_use_local_configs()
+        try:
+            self.wf_use_local_configs()
+        except FileNotFoundError as e:
+            log.error("Error editing pipeline config file to use local configs!")
+            log.critical(e)
+            sys.exit(1)
 
         # Download the singularity images
-        if self.singularity:
+        if self.container == "singularity":
             self.find_container_images()
-            self.get_singularity_images()
+            try:
+                self.get_singularity_images()
+            except OSError as e:
+                log.critical(f"[red]{e}[/]")
+                sys.exit(1)
 
         # Compress into an archive
         if self.compress_type is not None:
             log.info("Compressing download..")
             self.compress_download()
 
-    def fetch_workflow_details(self, wfs):
-        """Fetches details of a nf-core workflow to download.
+    def prompt_pipeline_name(self):
+        """Prompt for the pipeline name if not set with a flag"""
 
-        Args:
-            wfs (nf_core.list.Workflows): A nf_core.list.Workflows object
+        if self.pipeline is None:
+            stderr.print("Specify the name of a nf-core pipeline or a GitHub repository name (user/repo).")
+            self.pipeline = nf_core.utils.prompt_remote_pipeline_name(self.wfs)
 
-        Raises:
-            LockupError, if the pipeline can not be found.
-        """
-        wfs.get_remote_workflows()
+    def prompt_release(self):
+        """Prompt for pipeline release / branch"""
+        # Prompt user for release tag if '--release' was not set
+        if self.release is None:
+            self.release = nf_core.utils.prompt_pipeline_release_branch(self.wf_releases, self.wf_branches)
 
-        # Get workflow download details
-        for wf in wfs.remote_workflows:
-            if wf.full_name == self.pipeline or wf.name == self.pipeline:
+    def get_release_hash(self):
+        """Find specified release / branch hash"""
 
-                # Set pipeline name
-                self.wf_name = wf.name
+        # Branch
+        if self.release in self.wf_branches.keys():
+            self.wf_sha = self.wf_branches[self.release]
 
-                # Find latest release hash
-                if self.release is None and len(wf.releases) > 0:
-                    # Sort list of releases so that most recent is first
-                    wf.releases = sorted(wf.releases, key=lambda k: k.get("published_at_timestamp", 0), reverse=True)
-                    self.release = wf.releases[0]["tag_name"]
-                    self.wf_sha = wf.releases[0]["tag_sha"]
-                    log.debug("No release specified. Using latest release: {}".format(self.release))
-                # Find specified release hash
-                elif self.release is not None:
-                    for r in wf.releases:
-                        if r["tag_name"] == self.release.lstrip("v"):
-                            self.wf_sha = r["tag_sha"]
-                            break
-                    else:
-                        log.error("Not able to find release '{}' for {}".format(self.release, wf.full_name))
-                        log.info(
-                            "Available {} releases: {}".format(
-                                wf.full_name, ", ".join([r["tag_name"] for r in wf.releases])
-                            )
-                        )
-                        raise LookupError("Not able to find release '{}' for {}".format(self.release, wf.full_name))
-
-                # Must be a dev-only pipeline
-                elif not self.release:
-                    self.release = "dev"
-                    self.wf_sha = "master"  # Cheating a little, but GitHub download link works
-                    log.warning(
-                        "Pipeline is in development - downloading current code on master branch.\n"
-                        + "This is likely to change soon should not be considered fully reproducible."
-                    )
-
-                # Set outdir name if not defined
-                if not self.outdir:
-                    self.outdir = "nf-core-{}".format(wf.name)
-                    if self.release is not None:
-                        self.outdir += "-{}".format(self.release)
-
-                # Set the download URL and return
-                self.wf_download_url = "https://github.com/{}/archive/{}.zip".format(wf.full_name, self.wf_sha)
-                return
-
-        # If we got this far, must not be a nf-core pipeline
-        if self.pipeline.count("/") == 1:
-            # Looks like a GitHub address - try working with this repo
-            log.warning("Pipeline name doesn't match any nf-core workflows")
-            log.info("Pipeline name looks like a GitHub address - attempting to download anyway")
-            self.wf_name = self.pipeline
-            if not self.release:
-                self.release = "master"
-            self.wf_sha = self.release
-            if not self.outdir:
-                self.outdir = self.pipeline.replace("/", "-").lower()
-                if self.release is not None:
-                    self.outdir += "-{}".format(self.release)
-            # Set the download URL and return
-            self.wf_download_url = "https://github.com/{}/archive/{}.zip".format(self.pipeline, self.release)
+        # Release
         else:
-            log.error("Not able to find pipeline '{}'".format(self.pipeline))
-            log.info("Available pipelines: {}".format(", ".join([w.name for w in wfs.remote_workflows])))
-            raise LookupError("Not able to find pipeline '{}'".format(self.pipeline))
+            for r in self.wf_releases:
+                if r["tag_name"] == self.release:
+                    self.wf_sha = r["tag_sha"]
+                    break
+
+            # Can't find the release or branch - throw an error
+            else:
+                log.info(
+                    "Available {} releases: '{}'".format(
+                        self.pipeline, "', '".join([r["tag_name"] for r in self.wf_releases])
+                    )
+                )
+                log.info("Available {} branches: '{}'".format(self.pipeline, "', '".join(self.wf_branches.keys())))
+                raise AssertionError(
+                    "Not able to find release / branch '{}' for {}".format(self.release, self.pipeline)
+                )
+
+        # Set the outdir
+        if not self.outdir:
+            self.outdir = "{}-{}".format(self.pipeline.replace("/", "-").lower(), self.release)
+
+        # Set the download URL and return
+        self.wf_download_url = "https://github.com/{}/archive/{}.zip".format(self.pipeline, self.wf_sha)
+
+    def prompt_container_download(self):
+        """Prompt whether to download container images or not"""
+
+        if self.container is None:
+            stderr.print("\nIn addition to the pipeline code, this tool can download software containers.")
+            self.container = questionary.select(
+                "Download software container images:",
+                choices=["none", "singularity"],
+                style=nf_core.utils.nfcore_question_style,
+            ).unsafe_ask()
+
+    def prompt_use_singularity_cachedir(self):
+        """Prompt about using $NXF_SINGULARITY_CACHEDIR if not already set"""
+        if (
+            self.container == "singularity"
+            and os.environ.get("NXF_SINGULARITY_CACHEDIR") is None
+            and stderr.is_interactive  # Use rich auto-detection of interactive shells
+        ):
+            stderr.print(
+                "\nNextflow and nf-core can use an environment variable called [blue]$NXF_SINGULARITY_CACHEDIR[/] that is a path to a directory where remote Singularity images are stored. "
+                "This allows downloaded images to be cached in a central location."
+            )
+            if rich.prompt.Confirm.ask(
+                f"[blue bold]?[/] [bold]Define [blue not bold]$NXF_SINGULARITY_CACHEDIR[/] for a shared Singularity image download folder?[/]"
+            ):
+                # Prompt user for a cache directory path
+                cachedir_path = None
+                while cachedir_path is None:
+                    prompt_cachedir_path = questionary.path(
+                        "Specify the path:", only_directories=True, style=nf_core.utils.nfcore_question_style
+                    ).unsafe_ask()
+                    cachedir_path = os.path.abspath(os.path.expanduser(prompt_cachedir_path))
+                    if prompt_cachedir_path == "":
+                        log.error(f"Not using [blue]$NXF_SINGULARITY_CACHEDIR[/]")
+                        cachedir_path = False
+                    elif not os.path.isdir(cachedir_path):
+                        log.error(f"'{cachedir_path}' is not a directory.")
+                        cachedir_path = None
+                if cachedir_path:
+                    os.environ["NXF_SINGULARITY_CACHEDIR"] = cachedir_path
+
+                    # Ask if user wants this set in their .bashrc
+                    bashrc_path = os.path.expanduser("~/.bashrc")
+                    if not os.path.isfile(bashrc_path):
+                        bashrc_path = os.path.expanduser("~/.bash_profile")
+                        if not os.path.isfile(bashrc_path):
+                            bashrc_path = False
+                    if bashrc_path:
+                        stderr.print(
+                            f"\nSo that [blue]$NXF_SINGULARITY_CACHEDIR[/] is always defined, you can add it to your [blue not bold]~/{os.path.basename(bashrc_path)}[/] file ."
+                            "This will then be autmoatically set every time you open a new terminal. We can add the following line to this file for you: \n"
+                            f'[blue]export NXF_SINGULARITY_CACHEDIR="{cachedir_path}"[/]'
+                        )
+                        append_to_file = rich.prompt.Confirm.ask(
+                            f"[blue bold]?[/] [bold]Add to [blue not bold]~/{os.path.basename(bashrc_path)}[/] ?[/]"
+                        )
+                        if append_to_file:
+                            with open(os.path.expanduser(bashrc_path), "a") as f:
+                                f.write(
+                                    "\n\n#######################################\n"
+                                    f"## Added by `nf-core download` v{nf_core.__version__} ##\n"
+                                    + f'export NXF_SINGULARITY_CACHEDIR="{cachedir_path}"'
+                                    + "\n#######################################\n"
+                                )
+                            log.info(f"Successfully wrote to [blue]{bashrc_path}[/]")
+                            log.warning(
+                                "You will need reload your terminal after the download completes for this to take effect."
+                            )
+
+    def prompt_singularity_cachedir_only(self):
+        """Ask if we should *only* use $NXF_SINGULARITY_CACHEDIR without copying into target"""
+        if (
+            self.singularity_cache_only is None
+            and self.container == "singularity"
+            and os.environ.get("NXF_SINGULARITY_CACHEDIR") is not None
+        ):
+            stderr.print(
+                "\nIf you are working on the same system where you will run Nextflow, you can leave the downloaded images in the "
+                "[blue not bold]$NXF_SINGULARITY_CACHEDIR[/] folder, Nextflow will automatically find them. "
+                "However if you will transfer the downloaded files to a different system then they should be copied to the target folder."
+            )
+            self.singularity_cache_only = rich.prompt.Confirm.ask(
+                f"[blue bold]?[/] [bold]Copy singularity images from [blue not bold]$NXF_SINGULARITY_CACHEDIR[/] to the target folder?[/]"
+            )
+
+        # Sanity check, for when passed as a cli flag
+        if self.singularity_cache_only and self.container != "singularity":
+            raise AssertionError("Command has '--singularity-cache-only' set, but '--container' is not 'singularity'")
+
+    def prompt_compression_type(self):
+        """Ask user if we should compress the downloaded files"""
+        if self.compress_type is None:
+            stderr.print(
+                "\nIf transferring the downloaded files to another system, it can be convenient to have everything compressed in a single file."
+            )
+            if self.container == "singularity":
+                stderr.print(
+                    "[bold]This is [italic]not[/] recommended when downloading Singularity images, as it can take a long time and saves very little space."
+                )
+            self.compress_type = questionary.select(
+                "Choose compression type:",
+                choices=[
+                    "none",
+                    "tar.gz",
+                    "tar.bz2",
+                    "zip",
+                ],
+                style=nf_core.utils.nfcore_question_style,
+            ).unsafe_ask()
+
+        # Correct type for no-compression
+        if self.compress_type == "none":
+            self.compress_type = None
 
     def download_wf_files(self):
         """Downloads workflow files from GitHub to the :attr:`self.outdir`."""
@@ -255,7 +357,7 @@ class DownloadWorkflow(object):
         zipfile.extractall(self.outdir)
 
         # Rename the internal directory name to be more friendly
-        gh_name = "{}-{}".format(self.wf_name, self.wf_sha).split("/")[-1]
+        gh_name = "{}-{}".format(self.pipeline, self.wf_sha).split("/")[-1]
         os.rename(os.path.join(self.outdir, gh_name), os.path.join(self.outdir, "workflow"))
 
         # Make downloaded files executable
@@ -286,7 +388,7 @@ class DownloadWorkflow(object):
         """Edit the downloaded nextflow.config file to use the local config files"""
         nfconfig_fn = os.path.join(self.outdir, "workflow", "nextflow.config")
         find_str = "https://raw.githubusercontent.com/nf-core/configs/${params.custom_config_version}"
-        repl_str = "../configs/"
+        repl_str = "${projectDir}/../configs/"
         log.debug("Editing 'params.custom_config_base' in '{}'".format(nfconfig_fn))
 
         # Load the nextflow.config file into memory
@@ -297,7 +399,7 @@ class DownloadWorkflow(object):
         nfconfig = nfconfig.replace(find_str, repl_str)
 
         # Append the singularity.cacheDir to the end if we need it
-        if self.singularity and not self.singularity_cache_only:
+        if self.container == "singularity" and not self.singularity_cache_only:
             nfconfig += (
                 f"\n\n// Added by `nf-core download` v{nf_core.__version__} //\n"
                 + 'singularity.cacheDir = "${projectDir}/../singularity-images/"'
@@ -318,7 +420,8 @@ class DownloadWorkflow(object):
         `nextflow config` at the time of writing, so we scrape the pipeline files.
         """
 
-        log.info("Fetching container names for workflow")
+        log.debug("Fetching container names for workflow")
+        containers_raw = []
 
         # Use linting code to parse the pipeline nextflow config
         self.nf_config = nf_core.utils.fetch_wf_config(os.path.join(self.outdir, "workflow"))
@@ -326,7 +429,7 @@ class DownloadWorkflow(object):
         # Find any config variables that look like a container
         for k, v in self.nf_config.items():
             if k.startswith("process.") and k.endswith(".container"):
-                self.containers.append(v.strip('"').strip("'"))
+                containers_raw.append(v.strip('"').strip("'"))
 
         # Recursive search through any DSL2 module files for container spec lines.
         for subdir, dirs, files in os.walk(os.path.join(self.outdir, "workflow", "modules")):
@@ -343,15 +446,26 @@ class DownloadWorkflow(object):
                         # If we have matches, save the first one that starts with http
                         for m in matches:
                             if m.startswith("http"):
-                                self.containers.append(m.strip('"').strip("'"))
+                                containers_raw.append(m.strip('"').strip("'"))
                                 break
                         # If we get here then we didn't call break - just save the first match
                         else:
                             if len(matches) > 0:
-                                self.containers.append(matches[0].strip('"').strip("'"))
+                                containers_raw.append(matches[0].strip('"').strip("'"))
 
         # Remove duplicates and sort
-        self.containers = sorted(list(set(self.containers)))
+        containers_raw = sorted(list(set(containers_raw)))
+
+        # Strip any container names that have dynamic names - eg. {params.foo}
+        self.containers = []
+        for container in containers_raw:
+            if "{" in container and "}" in container:
+                log.error(
+                    f"[red]Container name [green]'{container}'[/] has dynamic Nextflow logic in name - skipping![/]"
+                )
+                log.info("Please use a 'nextflow run' command to fetch this container. Ask on Slack if you need help.")
+            else:
+                self.containers.append(container)
 
         log.info("Found {} container{}".format(len(self.containers), "s" if len(self.containers) > 1 else ""))
 
@@ -361,11 +475,6 @@ class DownloadWorkflow(object):
         if len(self.containers) == 0:
             log.info("No container names found in workflow")
         else:
-            if not os.environ.get("NXF_SINGULARITY_CACHEDIR"):
-                log.info(
-                    "[magenta]Tip: Set env var $NXF_SINGULARITY_CACHEDIR to use a central cache for container downloads"
-                )
-
             with DownloadProgress() as progress:
                 task = progress.add_task("all_containers", total=len(self.containers), progress_type="summary")
 
@@ -408,6 +517,10 @@ class DownloadWorkflow(object):
                     # Pull using singularity
                     containers_pull.append([container, out_path, cache_path])
 
+                # Exit if we need to pull images and Singularity is not installed
+                if len(containers_pull) > 0 and shutil.which("singularity") is None:
+                    raise OSError("Singularity is needed to pull images, but it is not installed")
+
                 # Go through each method of fetching containers in order
                 for container in containers_exist:
                     progress.update(task, description="Image file exists")
@@ -491,8 +604,6 @@ class DownloadWorkflow(object):
             out_name = out_name[:-4]
         # Strip : and / characters
         out_name = out_name.replace("/", "-").replace(":", "-")
-        # Stupid Docker Hub not allowing hyphens
-        out_name = out_name.replace("nfcore", "nf-core")
         # Add file extension
         out_name = out_name + extension
 
@@ -610,35 +721,25 @@ class DownloadWorkflow(object):
         # Progress bar to show that something is happening
         task = progress.add_task(container, start=False, total=False, progress_type="singularity_pull", current_log="")
 
-        # Try to use singularity to pull image
-        try:
-            # Run the singularity pull command
-            proc = subprocess.Popen(
-                singularity_command,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.STDOUT,
-                universal_newlines=True,
-                bufsize=1,
-            )
-            for line in proc.stdout:
-                log.debug(line.strip())
-                progress.update(task, current_log=line.strip())
+        # Run the singularity pull command
+        proc = subprocess.Popen(
+            singularity_command,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            universal_newlines=True,
+            bufsize=1,
+        )
+        for line in proc.stdout:
+            log.debug(line.strip())
+            progress.update(task, current_log=line.strip())
 
-            # Copy cached download if we are using the cache
-            if cache_path:
-                log.debug("Copying {} from cache: '{}'".format(container, os.path.basename(out_path)))
-                progress.update(task, current_log="Copying from cache to target directory")
-                shutil.copyfile(cache_path, out_path)
+        # Copy cached download if we are using the cache
+        if cache_path:
+            log.debug("Copying {} from cache: '{}'".format(container, os.path.basename(out_path)))
+            progress.update(task, current_log="Copying from cache to target directory")
+            shutil.copyfile(cache_path, out_path)
 
-            progress.remove_task(task)
-
-        except OSError as e:
-            if e.errno == errno.ENOENT:
-                # Singularity is not installed
-                log.error("Singularity is not installed!")
-            else:
-                # Something else went wrong with singularity command
-                raise e
+        progress.remove_task(task)
 
     def compress_download(self):
         """Take the downloaded files and make a compressed .tar.gz archive."""
@@ -650,7 +751,7 @@ class DownloadWorkflow(object):
             with tarfile.open(self.output_filename, "w:{}".format(ctype)) as tar:
                 tar.add(self.outdir, arcname=os.path.basename(self.outdir))
             tar_flags = "xzf" if ctype == "gz" else "xjf"
-            log.info("Command to extract files: tar -{} {}".format(tar_flags, self.output_filename))
+            log.info(f"Command to extract files: [bright_magenta]tar -{tar_flags} {self.output_filename}[/]")
 
         # .zip files
         if self.compress_type == "zip":
@@ -662,10 +763,10 @@ class DownloadWorkflow(object):
                         filePath = os.path.join(folderName, filename)
                         # Add file to zip
                         zipObj.write(filePath)
-            log.info("Command to extract files: unzip {}".format(self.output_filename))
+            log.info(f"Command to extract files: [bright_magenta]unzip {self.output_filename}[/]")
 
         # Delete original files
-        log.debug("Deleting uncompressed files: {}".format(self.outdir))
+        log.debug(f"Deleting uncompressed files: '{self.outdir}'")
         shutil.rmtree(self.outdir)
 
         # Caclualte md5sum for output file
@@ -691,7 +792,7 @@ class DownloadWorkflow(object):
         file_hash = hash_md5.hexdigest()
 
         if expected is None:
-            log.info("MD5 checksum for {}: {}".format(fname, file_hash))
+            log.info("MD5 checksum for '{}': [blue]{}[/]".format(fname, file_hash))
         else:
             if file_hash == expected:
                 log.debug("md5 sum of image matches expected: {}".format(expected))
