@@ -14,6 +14,7 @@ import questionary
 import re
 import subprocess
 import webbrowser
+import requests
 
 import nf_core.schema, nf_core.utils
 
@@ -21,7 +22,7 @@ log = logging.getLogger(__name__)
 
 
 class Launch(object):
-    """ Class to hold config option to launch a pipeline """
+    """Class to hold config option to launch a pipeline"""
 
     def __init__(
         self,
@@ -56,7 +57,11 @@ class Launch(object):
         if self.web_id:
             self.web_schema_launch_web_url = "{}?id={}".format(self.web_schema_launch_url, web_id)
             self.web_schema_launch_api_url = "{}?id={}&api=true".format(self.web_schema_launch_url, web_id)
-        self.nextflow_cmd = "nextflow run {}".format(self.pipeline)
+        self.nextflow_cmd = None
+
+        # Fetch remote workflows
+        self.wfs = nf_core.list.Workflows()
+        self.wfs.get_remote_workflows()
 
         # Prepend property names with a single hyphen in case we have parameters with the same ID
         self.nxf_flag_schema = {
@@ -93,12 +98,24 @@ class Launch(object):
 
     def launch_pipeline(self):
 
-        # Check that we have everything we need
+        # Prompt for pipeline if not supplied and no web launch ID
         if self.pipeline is None and self.web_id is None:
-            log.error(
-                "Either a pipeline name or web cache ID is required. Please see nf-core launch --help for more information."
-            )
-            return False
+            launch_type = questionary.select(
+                "Launch local pipeline or remote GitHub pipeline?",
+                choices=["Remote pipeline", "Local path"],
+                style=nf_core.utils.nfcore_question_style,
+            ).unsafe_ask()
+
+            if launch_type == "Remote pipeline":
+                try:
+                    self.pipeline = nf_core.utils.prompt_remote_pipeline_name(self.wfs)
+                except AssertionError as e:
+                    log.error(e.args[0])
+                    return False
+            else:
+                self.pipeline = questionary.path(
+                    "Path to workflow:", style=nf_core.utils.nfcore_question_style
+                ).unsafe_ask()
 
         # Check if the output file exists already
         if os.path.exists(self.params_out):
@@ -110,7 +127,9 @@ class Launch(object):
                 log.info("Exiting. Use --params-out to specify a custom filename.")
                 return False
 
-        log.info("This tool ignores any pipeline parameter defaults overwritten by Nextflow config files or profiles\n")
+        log.info(
+            "NOTE: This tool ignores any pipeline parameter defaults overwritten by Nextflow config files or profiles\n"
+        )
 
         # Check if we have a web ID
         if self.web_id is not None:
@@ -163,21 +182,33 @@ class Launch(object):
         self.launch_workflow()
 
     def get_pipeline_schema(self):
-        """ Load and validate the schema from the supplied pipeline """
+        """Load and validate the schema from the supplied pipeline"""
 
         # Set up the schema
         self.schema_obj = nf_core.schema.PipelineSchema()
 
         # Check if this is a local directory
-        if os.path.exists(self.pipeline):
+        localpath = os.path.abspath(os.path.expanduser(self.pipeline))
+        if os.path.exists(localpath):
             # Set the nextflow launch command to use full paths
-            self.nextflow_cmd = "nextflow run {}".format(os.path.abspath(self.pipeline))
+            self.pipeline = localpath
+            self.nextflow_cmd = f"nextflow run {localpath}"
         else:
             # Assume nf-core if no org given
             if self.pipeline.count("/") == 0:
-                self.nextflow_cmd = "nextflow run nf-core/{}".format(self.pipeline)
-            # Add revision flag to commands if set
-            if self.pipeline_revision:
+                self.pipeline = f"nf-core/{self.pipeline}"
+            self.nextflow_cmd = "nextflow run {}".format(self.pipeline)
+
+            if not self.pipeline_revision:
+                try:
+                    self.pipeline, wf_releases, wf_branches = nf_core.utils.get_repo_releases_branches(
+                        self.pipeline, self.wfs
+                    )
+                except AssertionError as e:
+                    log.error(e)
+                    return False
+
+                self.pipeline_revision = nf_core.utils.prompt_pipeline_release_branch(wf_releases, wf_branches)
                 self.nextflow_cmd += " -r {}".format(self.pipeline_revision)
 
         # Get schema from name, load it and lint it
@@ -193,7 +224,7 @@ class Launch(object):
             if not os.path.exists(os.path.join(self.schema_obj.pipeline_dir, "nextflow.config")) and not os.path.exists(
                 os.path.join(self.schema_obj.pipeline_dir, "main.nf")
             ):
-                log.error("Could not find a main.nf or nextfow.config file, are you sure this is a pipeline?")
+                log.error("Could not find a 'main.nf' or 'nextflow.config' file, are you sure this is a pipeline?")
                 return False
 
             # Build a schema for this pipeline
@@ -224,7 +255,7 @@ class Launch(object):
             self.schema_obj.validate_params()
 
     def merge_nxf_flag_schema(self):
-        """ Take the Nextflow flag schema and merge it with the pipeline schema """
+        """Take the Nextflow flag schema and merge it with the pipeline schema"""
         # Add the coreNextflow subschema to the schema definitions
         if "definitions" not in self.schema_obj.schema:
             self.schema_obj.schema["definitions"] = {}
@@ -236,7 +267,7 @@ class Launch(object):
         self.schema_obj.schema["allOf"].insert(0, {"$ref": "#/definitions/coreNextflow"})
 
     def prompt_web_gui(self):
-        """ Ask whether to use the web-based or cli wizard to collect params """
+        """Ask whether to use the web-based or cli wizard to collect params"""
         log.info(
             "[magenta]Would you like to enter pipeline parameters using a web-based interface or a command-line wizard?"
         )
@@ -251,7 +282,7 @@ class Launch(object):
         return answer["use_web_gui"] == "Web based"
 
     def launch_web_gui(self):
-        """ Send schema to nf-core website and launch input GUI """
+        """Send schema to nf-core website and launch input GUI"""
 
         content = {
             "post_content": "json_schema_launcher",
@@ -270,6 +301,7 @@ class Launch(object):
         try:
             assert "api_url" in web_response
             assert "web_url" in web_response
+            # DO NOT FIX THIS TYPO. Needs to stay in sync with the website. Maintaining for backwards compatability.
             assert web_response["status"] == "recieved"
         except AssertionError:
             log.debug("Response content:\n{}".format(json.dumps(web_response, indent=4)))
@@ -356,7 +388,7 @@ class Launch(object):
                     params[param_id] = filter_func(params[param_id])
 
     def prompt_schema(self):
-        """ Go through the pipeline schema and prompt user to change defaults """
+        """Go through the pipeline schema and prompt user to change defaults"""
         answers = {}
         # Start with the subschema in the definitions - use order of allOf
         for allOf in self.schema_obj.schema.get("allOf", []):
@@ -618,12 +650,23 @@ class Launch(object):
             console.print("(Use arrow keys)", style="italic", highlight=False)
 
     def strip_default_params(self):
-        """ Strip parameters if they have not changed from the default """
+        """Strip parameters if they have not changed from the default"""
 
-        # Schema defaults
-        for param_id, val in self.schema_obj.schema_defaults.items():
-            if self.schema_obj.input_params.get(param_id) == val:
-                del self.schema_obj.input_params[param_id]
+        # Go through each supplied parameter (force list so we can delete in the loop)
+        for param_id in list(self.schema_obj.input_params.keys()):
+            val = self.schema_obj.input_params[param_id]
+
+            # Params with a schema default
+            if param_id in self.schema_obj.schema_defaults:
+                # Strip if param is same as the schema default
+                if val == self.schema_obj.schema_defaults[param_id]:
+                    del self.schema_obj.input_params[param_id]
+
+            # Params with no schema default
+            else:
+                # Strip if param is empty
+                if val is False or val is None or val == "":
+                    del self.schema_obj.input_params[param_id]
 
         # Nextflow flag defaults
         for param_id, val in self.nxf_flag_schema["coreNextflow"]["properties"].items():
@@ -631,7 +674,7 @@ class Launch(object):
                 del self.nxf_flags[param_id]
 
     def build_command(self):
-        """ Build the nextflow run command based on what we know """
+        """Build the nextflow run command based on what we know"""
 
         # Core nextflow options
         for flag, val in self.nxf_flags.items():
@@ -657,12 +700,15 @@ class Launch(object):
                     # Boolean flags like --saveTrimmed
                     if isinstance(val, bool) and val:
                         self.nextflow_cmd += " --{}".format(param)
+                    # No quotes for numbers
+                    elif (isinstance(val, int) or isinstance(val, float)) and val:
+                        self.nextflow_cmd += " --{} {}".format(param, str(val).replace('"', '\\"'))
                     # everything else
                     else:
                         self.nextflow_cmd += ' --{} "{}"'.format(param, str(val).replace('"', '\\"'))
 
     def launch_workflow(self):
-        """ Launch nextflow if required  """
+        """Launch nextflow if required"""
         log.info("[bold underline]Nextflow command:[/]\n[magenta]{}\n\n".format(self.nextflow_cmd))
 
         if Confirm.ask("Do you want to run this command now? "):
