@@ -5,9 +5,9 @@ Tests Nextflow-based pipelines to check that they adhere to
 the nf-core community guidelines.
 """
 
-from rich.console import Console
 from rich.markdown import Markdown
 from rich.table import Table
+from rich.panel import Panel
 import datetime
 import git
 import json
@@ -19,12 +19,15 @@ import rich.progress
 import yaml
 
 import nf_core.utils
+import nf_core.lint_utils
+from nf_core.lint_utils import console
+from nf_core.modules.lint import ModuleLint
 
 log = logging.getLogger(__name__)
 
 
 def run_linting(
-    pipeline_dir, release_mode=False, fix=(), show_passed=False, fail_ignored=False, md_fn=None, json_fn=None
+    pipeline_dir, release_mode=False, fix=(), key=(), show_passed=False, fail_ignored=False, md_fn=None, json_fn=None
 ):
     """Runs all nf-core linting checks on a given Nextflow pipeline project
     in either `release` mode or `normal` mode (default). Returns an object
@@ -40,24 +43,42 @@ def run_linting(
     """
 
     # Create the lint object
-    lint_obj = PipelineLint(pipeline_dir, release_mode, fix, fail_ignored)
+    lint_obj = PipelineLint(pipeline_dir, release_mode, fix, key, fail_ignored)
 
     # Load the various pipeline configs
     lint_obj._load_lint_config()
     lint_obj._load_pipeline_config()
-    lint_obj._load_conda_environment()
     lint_obj._list_files()
 
-    # Run the linting tests
+    # Create the modules lint object
+    module_lint_obj = ModuleLint(pipeline_dir)
+
+    # Run only the tests we want
+    module_lint_tests = ("module_changes", "module_version")
+    module_lint_obj.filter_tests_by_key(module_lint_tests)
+
+    # Set up files for modules linting test
+    module_lint_obj.set_up_pipeline_files()
+
+    # Run the pipeline linting tests
     try:
         lint_obj._lint_pipeline()
     except AssertionError as e:
         log.critical("Critical error: {}".format(e))
         log.info("Stopping tests...")
-        return lint_obj
+        return lint_obj, module_lint_obj
+
+    # Run the module lint tests
+    if len(module_lint_obj.all_local_modules) > 0:
+        module_lint_obj.lint_modules(module_lint_obj.all_local_modules, local=True)
+    if len(module_lint_obj.all_nfcore_modules) > 0:
+        module_lint_obj.lint_modules(module_lint_obj.all_nfcore_modules, local=False)
 
     # Print the results
     lint_obj._print_results(show_passed)
+    module_lint_obj._print_results(show_passed)
+    nf_core.lint_utils.print_joint_summary(lint_obj, module_lint_obj)
+    nf_core.lint_utils.print_fixes(lint_obj, module_lint_obj)
 
     # Save results to Markdown file
     if md_fn is not None:
@@ -75,7 +96,7 @@ def run_linting(
         if release_mode:
             log.info("Reminder: Lint tests were run in --release mode.")
 
-    return lint_obj
+    return lint_obj, module_lint_obj
 
 
 class PipelineLint(nf_core.utils.Pipeline):
@@ -97,29 +118,32 @@ class PipelineLint(nf_core.utils.Pipeline):
         warned (list): A list of tuples of the form: ``(<warned no>, <reason>)``
     """
 
+    from .actions_awsfulltest import actions_awsfulltest
+    from .actions_awstest import actions_awstest
+    from .actions_ci import actions_ci
+    from .actions_schema_validation import actions_schema_validation
     from .files_exist import files_exist
     from .files_unchanged import files_unchanged
+    from .merge_markers import merge_markers
+    from .modules_json import modules_json
     from .nextflow_config import nextflow_config
-    from .actions_ci import actions_ci
-    from .actions_awstest import actions_awstest
-    from .actions_awsfulltest import actions_awsfulltest
-    from .readme import readme
-    from .version_consistency import version_consistency
-    from .conda_env_yaml import conda_env_yaml
-    from .conda_dockerfile import conda_dockerfile
-    from .pipeline_todos import pipeline_todos
     from .pipeline_name_conventions import pipeline_name_conventions
-    from .template_strings import template_strings
+    from .pipeline_todos import pipeline_todos
+    from .readme import readme
     from .schema_lint import schema_lint
     from .schema_params import schema_params
-    from .actions_schema_validation import actions_schema_validation
-    from .merge_markers import merge_markers
+    from .schema_description import schema_description
+    from .template_strings import template_strings
+    from .version_consistency import version_consistency
 
-    def __init__(self, wf_path, release_mode=False, fix=(), fail_ignored=False):
-        """ Initialise linting object """
+    def __init__(self, wf_path, release_mode=False, fix=(), key=(), fail_ignored=False):
+        """Initialise linting object"""
 
         # Initialise the parent object
-        super().__init__(wf_path)
+        try:
+            super().__init__(wf_path)
+        except UserWarning:
+            raise
 
         self.lint_config = {}
         self.release_mode = release_mode
@@ -138,19 +162,20 @@ class PipelineLint(nf_core.utils.Pipeline):
             "actions_awstest",
             "actions_awsfulltest",
             "readme",
-            "conda_env_yaml",
-            "conda_dockerfile",
             "pipeline_todos",
             "pipeline_name_conventions",
             "template_strings",
             "schema_lint",
             "schema_params",
+            "schema_description",
             "actions_schema_validation",
             "merge_markers",
+            "modules_json",
         ]
         if self.release_mode:
             self.lint_tests.extend(["version_consistency"])
         self.fix = fix
+        self.key = key
         self.progress_bar = None
 
     def _load(self):
@@ -164,24 +189,13 @@ class PipelineLint(nf_core.utils.Pipeline):
     def _load_lint_config(self):
         """Parse a pipeline lint config file.
 
-        Look for a file called either `.nf-core-lint.yml` or
-        `.nf-core-lint.yaml` in the pipeline root directory and parse it.
-        (`.yml` takes precedence).
+        Load the '.nf-core.yml'  config file and extract
+        the lint config from it
 
         Add parsed config to the `self.lint_config` class attribute.
         """
-        config_fn = os.path.join(self.wf_path, ".nf-core-lint.yml")
-
-        # Pick up the file if it's .yaml instead of .yml
-        if not os.path.isfile(config_fn):
-            config_fn = os.path.join(self.wf_path, ".nf-core-lint.yaml")
-
-        # Load the YAML
-        try:
-            with open(config_fn, "r") as fh:
-                self.lint_config = yaml.safe_load(fh)
-        except FileNotFoundError:
-            log.debug("No lint config file found: {}".format(config_fn))
+        tools_config = nf_core.utils.load_tools_config(self.wf_path)
+        self.lint_config = tools_config.get("lint", {})
 
         # Check if we have any keys that don't match lint test names
         for k in self.lint_config:
@@ -208,6 +222,21 @@ class PipelineLint(nf_core.utils.Pipeline):
                 )
             )
 
+        # Check that supplied test keys exist
+        bad_keys = [k for k in self.key if k not in self.lint_tests]
+        if len(bad_keys) > 0:
+            raise AssertionError(
+                "Test name{} not recognised: '{}'".format(
+                    "s" if len(bad_keys) > 1 else "",
+                    "', '".join(bad_keys),
+                )
+            )
+
+        # If -k supplied, only run these tests
+        if self.key:
+            log.info("Only running tests: '{}'".format("', '".join(self.key)))
+            self.lint_tests = [k for k in self.lint_tests if k in self.key]
+
         # Check that the pipeline_dir is a clean git repo
         if len(self.fix):
             log.info("Attempting to automatically fix failing tests")
@@ -257,7 +286,7 @@ class PipelineLint(nf_core.utils.Pipeline):
                 if test_results.get("could_fix", False):
                     self.could_fix.append(test_name)
 
-    def _print_results(self, show_passed=False):
+    def _print_results(self, show_passed):
         """Print linting results to the command line.
 
         Uses the ``rich`` library to print a set of formatted tables to the command line
@@ -265,7 +294,6 @@ class PipelineLint(nf_core.utils.Pipeline):
         """
 
         log.debug("Printing final results")
-        console = Console(force_terminal=nf_core.utils.rich_force_colors())
 
         # Helper function to format test links nicely
         def format_result(test_results, table):
@@ -282,6 +310,9 @@ class PipelineLint(nf_core.utils.Pipeline):
                 return "s"
             return ""
 
+        # Print lint results header
+        console.print(Panel("[magenta]General lint results"))
+
         # Table of passed tests
         if len(self.passed) > 0 and show_passed:
             table = Table(style="green", box=rich.box.ROUNDED)
@@ -317,6 +348,12 @@ class PipelineLint(nf_core.utils.Pipeline):
             table = format_result(self.failed, table)
             console.print(table)
 
+    def _print_summary(self):
+        def _s(some_list):
+            if len(some_list) != 1:
+                return "s"
+            return ""
+
         # Summary table
         summary_colour = "red" if len(self.failed) > 0 else "green"
         table = Table(box=rich.box.ROUNDED, style=summary_colour)
@@ -329,16 +366,6 @@ class PipelineLint(nf_core.utils.Pipeline):
         table.add_row(r"[red][✗] {:>3} Test{} Failed".format(len(self.failed), _s(self.failed)))
         console.print(table)
 
-        if len(self.could_fix):
-            fix_cmd = "nf-core lint {} --fix {}".format(self.wf_path, " --fix ".join(self.could_fix))
-            console.print(
-                f"\nTip: Some of these linting errors can automatically be resolved with the following command:\n\n[blue]    {fix_cmd}\n"
-            )
-        if len(self.fix):
-            console.print(
-                "Automatic fixes applied. Please check with 'git diff' and revert any changes you do not want with 'git checkout <file>'."
-            )
-
     def _get_results_md(self):
         """
         Create a markdown file suitable for posting in a GitHub comment.
