@@ -18,35 +18,33 @@ def files_unchanged(self):
 
     Files that must be unchanged::
 
-        '.gitattributes',
-        '.github/.dockstore.yml',
-        '.github/CONTRIBUTING.md',
-        '.github/ISSUE_TEMPLATE/bug_report.md',
-        '.github/ISSUE_TEMPLATE/config.yml',
-        '.github/ISSUE_TEMPLATE/feature_request.md',
-        '.github/markdownlint.yml',
-        '.github/PULL_REQUEST_TEMPLATE.md',
-        '.github/workflows/branch.yml',
-        '.github/workflows/linting_comment.yml',
-        '.github/workflows/linting.yml',
-        'assets/email_template.html',
-        'assets/email_template.txt',
-        'assets/nf-core-PIPELINE_logo.png',
-        'assets/sendmail_template.txt',
-        'bin/markdown_to_html.py',
-        'CODE_OF_CONDUCT.md',
-        'docs/images/nf-core-PIPELINE_logo.png',
-        'docs/README.md',
-        'lib/nfcore_external_java_deps.jar'
-        'lib/NfcoreSchema.groovy',
+        .gitattributes
+        .markdownlint.yml
+        .github/.dockstore.yml
+        .github/CONTRIBUTING.md
+        .github/ISSUE_TEMPLATE/bug_report.md
+        .github/ISSUE_TEMPLATE/config.yml
+        .github/ISSUE_TEMPLATE/feature_request.md
+        .github/PULL_REQUEST_TEMPLATE.md
+        .github/workflows/branch.yml
+        .github/workflows/linting_comment.yml
+        .github/workflows/linting.yml
+        assets/email_template.html
+        assets/email_template.txt
+        assets/nf-core-PIPELINE_logo.png
+        assets/sendmail_template.txt
+        CODE_OF_CONDUCT.md
+        docs/images/nf-core-PIPELINE_logo.png
+        docs/README.md'
+        lib/nfcore_external_java_deps.jar
+        lib/NfcoreSchema.groovy
+        lib/NfcoreTemplate.groovy
         ['LICENSE', 'LICENSE.md', 'LICENCE', 'LICENCE.md'], # NB: British / American spelling
 
     Files that can have additional content but must include the template contents::
 
-        '.github/workflows/push_dockerhub_dev.yml',
-        '.github/workflows/push_dockerhub_release.yml',
-        '.gitignore',
-        'assets/multiqc_config.yaml',
+        .gitignore
+        assets/multiqc_config.yaml
 
     .. tip:: You can configure the ``nf-core lint`` tests to ignore any of these checks by setting
              the ``files_unchanged`` key as follows in your linting config file. For example:
@@ -78,6 +76,7 @@ def files_unchanged(self):
     # List of lists. Passes if any of the files in the sublist are found.
     files_exact = [
         [".gitattributes"],
+        [".markdownlint.yml"],
         ["CODE_OF_CONDUCT.md"],
         ["LICENSE", "LICENSE.md", "LICENCE", "LICENCE.md"],  # NB: British / American spelling
         [os.path.join(".github", ".dockstore.yml")],
@@ -85,7 +84,6 @@ def files_unchanged(self):
         [os.path.join(".github", "ISSUE_TEMPLATE", "bug_report.md")],
         [os.path.join(".github", "ISSUE_TEMPLATE", "config.yml")],
         [os.path.join(".github", "ISSUE_TEMPLATE", "feature_request.md")],
-        [os.path.join(".github", "markdownlint.yml")],
         [os.path.join(".github", "PULL_REQUEST_TEMPLATE.md")],
         [os.path.join(".github", "workflows", "branch.yml")],
         [os.path.join(".github", "workflows", "linting_comment.yml")],
@@ -94,16 +92,15 @@ def files_unchanged(self):
         [os.path.join("assets", "email_template.txt")],
         [os.path.join("assets", "sendmail_template.txt")],
         [os.path.join("assets", f"nf-core-{short_name}_logo.png")],
-        [os.path.join("bin", "markdown_to_html.py")],
+        [os.path.join("bin", "scrape_software_versions.py")],
         [os.path.join("docs", "images", f"nf-core-{short_name}_logo.png")],
         [os.path.join("docs", "README.md")],
         [os.path.join("lib", "nfcore_external_java_deps.jar")],
         [os.path.join("lib", "NfcoreSchema.groovy")],
+        [os.path.join("lib", "NfcoreTemplate.groovy")],
     ]
     files_partial = [
         [".gitignore", "foo"],
-        [os.path.join(".github", "workflows", "push_dockerhub_dev.yml")],
-        [os.path.join(".github", "workflows", "push_dockerhub_release.yml")],
         [os.path.join("assets", "multiqc_config.yaml")],
     ]
 
